#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */
#include "usbdrv.h"
#define VENDOR_RQ_GET_LEVEL 0
#define VENDOR_RQ_ON_PUMP 1
#define VENDOR_RQ_OFF_PUMP 2
char in_c(char pin)
{
    DDRC &= ~(1<<pin);
    return ((PINC & (1<<pin))>>pin);    
} 
void out_c(char pin, char val)
{
    DDRC |= 1<<pin;
    if(val)
        PORTC |= 1<<pin;
    else
        PORTC &= ~(1<<pin);
}
uint16_t read_adc(uint8_t channel)
{
    ADMUX = 0b01000000; // เลือกใช้แรงดันอ้างอิงจากขา AREF
    ADMUX |= channel;   // ตั้ง MUX ให้ชี้ไปยัง channel
    ADCSRA = 0b11000110;
    while ((ADCSRA & (1<<ADSC))) // รอจนบิต ADSC (บิต 6) กลายเป็น 0
        ;
    return ADCL + ADCH*256;  // ผลลัพธ์ถูกเก็บอยู่ในรีจีสเตอร์ ADCL และ ADCH
}
usbMsgLen_t usbFunctionSetup(uchar data[8])
{
    usbRequest_t *rq = (void *)data;
    static uchar dataBuffer[1];  /* must stay valid when usbFunctionSetup returns */

    if (rq->bRequest == VENDOR_RQ_GET_LEVEL)
    {		dataBuffer[0] = 5;
	if(read_adc(3) != 0)
		dataBuffer[0] = 3;
	else if(read_adc(1) != 0)
                dataBuffer[0] =1;
//        else if (in_c(0))
	else if(read_adc(0) != 0)
                dataBuffer[0] = 0;
	else dataBuffer[0] = 6;
	usbMsgPtr = dataBuffer;
        return usbMsgPtr;
    }
    else if (rq->bRequest == VENDOR_RQ_ON_PUMP)
    {
		out_c(4,1);
        return 0;
    }
    else if (rq->bRequest == VENDOR_RQ_OFF_PUMP)
    {
                out_c(4,0);
        return 0;
    }

    return 0;   // default for not implemented requests: return no data back to host */
}

/* ------------------------------------------------------------------------- */

int main(void)
{
    DDRC  = 0b00010000;  // PC4 = Output, PC3..PC5 = Input
            0bxx0xxxxx;
         &= (0b           )

    PORTC = 0b00000000;  // PC7..PC0 = 0
    usbInit();
    usbDeviceDisconnect();  /* enforce re-enumeration, do this while interrupts are disabled! */
    _delay_ms(300);
    usbDeviceConnect();
    sei();
    for(;;){                /* main event loop */
        usbPoll();
	if(read_adc(0)==0) PORTC = 0b00010000;
	//_delay_ms(2000);
	if(read_adc(3)>=50) PORTC = 0b00000000;}
    return 0;
}
